aboutsummaryrefslogtreecommitdiff
path: root/src/asprintf.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/asprintf.c')
-rw-r--r--src/asprintf.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/asprintf.c b/src/asprintf.c
index a92b88a..2ae61e0 100644
--- a/src/asprintf.c
+++ b/src/asprintf.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -20,10 +20,10 @@
#include <stdlib.h>
#include <string.h>
#include <errno.h>
-#include "grecs.h"
+#include "argot.h"
int
-grecs_vasprintf(char **pbuf, size_t *psize, const char *fmt, va_list ap)
+argot_vasprintf(char **pbuf, size_t *psize, const char *fmt, va_list ap)
{
char *buf = *pbuf;
size_t buflen = *psize;
@@ -78,13 +78,13 @@ grecs_vasprintf(char **pbuf, size_t *psize, const char *fmt, va_list ap)
}
int
-grecs_asprintf(char **pbuf, size_t *psize, const char *fmt, ...)
+argot_asprintf(char **pbuf, size_t *psize, const char *fmt, ...)
{
int rc;
va_list ap;
va_start(ap, fmt);
- rc = grecs_vasprintf(pbuf, psize, fmt, ap);
+ rc = argot_vasprintf(pbuf, psize, fmt, ap);
va_end(ap);
return rc;
}
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.